slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDGetSignature

Get the signature matrix defining a hyperbolic singular value problem.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDGetSignature(SVD svd,Vec *omega)

Collective on svd

### Input Parameter

| svd | - the singular value solver context

### Output Parameter

| omega | - a vector containing the diagonal elements of the signature matrix

### See Also

SVDSetSignature()

### Level

intermediate

### Location

src/svd/interface/svdsetup.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages